DraggableState class

Constructors

DraggableState({double top = 0.0, double left = 0.0})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
left double
final
props List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
top double
final

Methods

copyWith({double? top, double? left}) DraggableState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited